@@ -1,8 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021, 2022 Oracle and its affiliates.
+# Copyright (c) 2021, 2022 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
+
 import logging
 
 from oci.ai_language import AIServiceLanguageClient
@@ -41,6 +42,8 @@ class OCIClientFactory:
     auth = authutil.resource_principal({"timeout": 6000})
     oc.OCIClientFactory(**auth).object_storage # Creates Object storage client with timeout set to 6000 using resource principal authentication
 
+    auth = authutil.create_signer("instance_principal")
+    oc.OCIClientFactory(**auth).object_storage # Creates Object storage client using instance principal authentication
     """
 
     def __init__(self, config={}, signer=None, client_kwargs=None):
