@@ -1,8 +1,9 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2021 Oracle and its affiliates.
+# Copyright (c) 2021, 2022 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
+
 import oci.data_science
 from ads.common.oci_mixin import OCIModelMixin
 
@@ -16,6 +17,10 @@ class OCIDataScienceMixin(OCIModelMixin):
     def client(self) -> oci.data_science.DataScienceClient:
         return super().client
 
+    @property
+    def client_composite(self) -> oci.data_science.DataScienceClientCompositeOperations:
+        return oci.data_science.DataScienceClientCompositeOperations(self.client)
+
 
 class DSCNotebookSession(OCIDataScienceMixin, oci.data_science.models.NotebookSession):
     """Represents a data science notebook session
