@@ -7,7 +7,7 @@
 import datetime
 import logging
 import time
-from typing import Union, List
+from typing import Dict, Union, List
 
 import oci.logging
 import oci.loggingsearch
@@ -22,6 +22,7 @@ logger = logging.getLogger(__name__)
 LOG_RECORDS_LIMIT = 100
 # The time interval in seconds between sending each request to pull logs
 LOG_INTERVAL = 3
+MAXIMUM_RETRY_COUNT = 20
 
 
 class SortOrder:
@@ -204,7 +205,7 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
     """Represents the OCI Log resource.
 
     Usage: (OCI requires display_name to be unique and it cannot contain space)
-    >>> log = OCILog.create(display_name="My_Log", log_group_id=LOG_GROUP_ID)
+    >>> log = OCILog(display_name="My_Log", log_group_id=LOG_GROUP_ID).create()
     Usually it is better to create a log using the create_log() method in OCILogGroup.
     >>> log.delete() # Delete the resource
     Get a log object from OCID
@@ -223,6 +224,8 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
             kwargs["log_type"] = log_type
         super().__init__(**kwargs)
         self._search_client = None
+        self.source = kwargs.get("source", None)
+        self.annotation = kwargs.get("annotation", None)
 
     @staticmethod
     def _get_log_group_id(log_ocid, compartment_ocid: str = None) -> str:
@@ -266,7 +269,7 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
             self.log_group_id, self.to_oci_model(oci.logging.models.CreateLogDetails)
         )
 
-    def sync(self) -> None:
+    def sync(self, **kwargs) -> None:
         """Refreshes the properties of the Log model
         OCI requires both Log OCID and Log group OCID to get the Log model.
 
@@ -274,7 +277,9 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
         """
         if not self.log_group_id:
             self.log_group_id = self._get_log_group_id(self.id, self.compartment_id)
-        self.update_from_oci_model(self.client.get_log(self.log_group_id, self.id).data)
+        self.update_from_oci_model(
+            self.client.get_log(self.log_group_id, self.id).data, **kwargs
+        )
         return self
 
     def delete(self):
@@ -443,11 +448,13 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
         # Build search query
         search_query = f'SEARCH "{self.compartment_id}/{self.log_group_id}/{self.id}"'
         filters = []
-        if source:
+
+        filter_source = source or self.source
+        if filter_source:
             # source = <OCID> is not allowed but source = *<OCID> works
-            if source.startswith("ocid1."):
-                source = "*" + source
-            filters = [f"source = '{source}'"] + filters
+            if filter_source.startswith("ocid1."):
+                filter_source = "*" + filter_source
+            filters = [f"source = '{filter_source}'"] + filters
 
         if log_filter:
             filters.append(log_filter)
@@ -517,6 +524,7 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
         limit: int = LOG_RECORDS_LIMIT,
         sort_by: str = "datetime",
         sort_order: str = SortOrder.DESC,
+        log_filter: str = None,
     ):
         """Returns the formatted log records.
 
@@ -534,6 +542,9 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
             The field for sorting the logs.
         sort_order: (str, optional). Defaults to "DESC".
             The sort order for the log records. Can be "ASC" or "DESC".
+        log_filter : (str, optional). Defaults to None.
+            Expression for filtering the logs.
+            This will be the WHERE clause of the query.
 
         Returns
         -------
@@ -551,6 +562,7 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
             limit=limit,
             sort_by=sort_by,
             sort_order=sort_order,
+            log_filter=log_filter,
         )
         logs = sorted((log.data for log in logs), key=lambda x: x.get("datetime"))
         logs = [log.get("logContent", {}) for log in logs]
@@ -568,6 +580,7 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
         source: str = None,
         limit=LOG_RECORDS_LIMIT,
         time_start: datetime.datetime = None,
+        log_filter: str = None,
     ) -> List[dict]:
         """Returns the most recent log records.
 
@@ -581,6 +594,9 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
         time_start: (datetime.datetime, optional)
             Starting time for the log query.
             Defaults to None. Logs up to 14 days from now will be returned.
+        log_filter : (str, optional). Defaults to None.
+            Expression for filtering the logs.
+            This will be the WHERE clause of the query.
 
         Returns
         -------
@@ -589,7 +605,11 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
             Each log record is a dictionary with the following keys: `id`, `time`, `message`.
         """
         return self._search_and_format(
-            source=source, limit=limit, sort_order=SortOrder.DESC, time_start=time_start
+            source=source,
+            limit=limit,
+            sort_order=SortOrder.DESC,
+            time_start=time_start,
+            log_filter=log_filter,
         )
 
     def head(
@@ -627,6 +647,7 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
         interval: int = LOG_INTERVAL,
         stop_condition: callable = None,
         time_start: datetime.datetime = None,
+        log_filter: str = None,
     ):
         """Streams logs to console/terminal until stop_condition() returns true.
 
@@ -641,6 +662,10 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
         time_start: datetime.datetime
             Starting time for the log query.
             Defaults to None. Logs up to 14 days from now will be returned.
+        log_filter : str, optional
+            Expression for filtering the logs.
+            This will be the WHERE clause of the query.
+            Defaults to None.
 
         Returns
         -------
@@ -659,12 +684,14 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
                 next_time_start = datetime.datetime.utcnow() - datetime.timedelta(
                     seconds=180
                 )
-                logs = self.tail(source, limit=None, time_start=time_start)
+                logs = self.tail(
+                    source, limit=None, time_start=time_start, log_filter=log_filter
+                )
                 # Update time_start if the tail() is successful
                 time_start = next_time_start
             except Exception:
                 exception_count += 1
-                if exception_count > 20:
+                if exception_count > MAXIMUM_RETRY_COUNT:
                     raise
                 else:
                     time.sleep(interval)
@@ -681,3 +708,427 @@ class OCILog(OCILoggingModelMixin, oci.logging.models.Log):
             if stop_condition and stop_condition():
                 return len(printed)
             time.sleep(interval)
+
+
+class ConsolidatedLog:
+    """Represents the Consolidated OCI Log resource.
+
+    Usage:
+    Initialize consolidated log instance for oci_log_one and oci_log_two
+    >>> oci_log_one = OCILog(
+    >>>     compartment_id=<compartment_id_one>,
+    >>>     id=<id_one>,
+    >>>     log_group_id=<log_group_id_one>,
+    >>>     annotation=<annotation_one>
+    >>> )
+    >>> oci_log_two = OCILog(
+    >>>     compartment_id=<compartment_id_two>,
+    >>>     id=<id_two>,
+    >>>     log_group_id=<log_group_id_two>,
+    >>>     annotation=<annotation_two>
+    >>> )
+    >>> consolidated_log = ConsolidatedLog(oci_log_one, oci_log_two)
+    Stream, sort and annotate the logs from oci_log_one and oci_log_two
+    >>> consolidated_log.stream()
+    Get the most recent 20 consolidated logs from oci_log_one and oci_log_two
+    >>> consolidated_log.tail(limit=20)
+    Get the most recent 20 raw logs from oci_log_one and oci_log_two
+    >>> consolidated_log.search(limit=20)
+    """
+
+    def __init__(self, *args) -> None:
+        """Initializes a consolidate log model instance.
+
+        Parameters
+        ----------
+        args:
+            A list of OCILog instance.
+        """
+        self.logging_instance = []
+        for arg in args:
+            if isinstance(arg, OCILog):
+                self.logging_instance.append(arg)
+            else:
+                raise ValueError(
+                    "Unrecognized type. ConsolidatedLog constructor requires OCILog instances as parameters."
+                )
+
+    def stream(
+        self,
+        source: str = None,
+        interval: int = LOG_INTERVAL,
+        stop_condition: callable = None,
+        time_start: datetime.datetime = None,
+        log_filter: str = None,
+    ):
+        """Streams consolidated logs to console/terminal until stop_condition() returns true.
+
+        Parameters
+        ----------
+        source : str, optional
+            Expression or OCID to filter the "source" field of the OCI log record.
+            Defaults to None.
+        interval : int, optional
+            The time interval between sending each request to pull logs from OCI logging service.
+            Defaults to 3.
+        stop_condition : callable, optional
+            A function to determine if the streaming should stop.
+            The log streaming will stop if the function returns true.
+            Defaults to None.
+        time_start : datetime.datetime, optional
+            Starting time for the log query.
+            Defaults to None.
+        log_filter : str, optional
+            Expression for filtering the logs. This will be the WHERE clause of the query.
+            Defaults to None.
+        """
+        self._print_log_annotation_message()
+        # Use a set to store the IDs of the printed messages
+        printed = set()
+        exception_count = 0
+        while True:
+            try:
+                # Tail the logs from time_start until now
+                # Logs may come in after the timestamp.
+                # For the next tail() call,
+                # use the time that's 3 minutes before now so that we can have some overlaps.
+                next_time_start = datetime.datetime.utcnow() - datetime.timedelta(
+                    seconds=180
+                )
+                logs = self._search_and_format(
+                    source=source,
+                    limit=None,
+                    sort_order=SortOrder.DESC,
+                    time_start=time_start,
+                    log_filter=log_filter,
+                )
+                # Update time_start if the tail() is successful
+                time_start = next_time_start
+            except Exception:
+                exception_count += 1
+                if exception_count > MAXIMUM_RETRY_COUNT:
+                    raise
+                else:
+                    time.sleep(interval)
+                    continue
+            for log in logs:
+                if log.get("id") not in printed:
+                    self._print_log_details(log)
+                    printed.add(log.get("id"))
+            if stop_condition and stop_condition():
+                return len(printed)
+            time.sleep(interval)
+
+    def tail(
+        self,
+        source: str = None,
+        limit: int = LOG_RECORDS_LIMIT,
+        time_start: datetime.datetime = None,
+        log_filter: str = None,
+    ) -> None:
+        """Returns the most recent consolidated log records.
+
+        Parameters
+        ----------
+        source : str, optional
+            Expression or OCID to filter the "source" field of the OCI log record.
+            Defaults to None.
+        limit : int, optional.
+            Maximum number of records to be returned.
+            If limit is set to None, all logs from time_start to now will be returned.
+            Defaults to 100.
+        time_start : datetime.datetime, optional
+            Starting time for the log query.
+            Defaults to None.
+        log_filter : str, optional
+            Expression for filtering the logs. This will be the WHERE clause of the query.
+            Defaults to None.
+        """
+        self._print(
+            self._search_and_format(
+                source=source,
+                limit=limit,
+                sort_order=SortOrder.DESC,
+                time_start=time_start,
+                log_filter=log_filter,
+            )
+        )
+
+    def head(
+        self,
+        source: str = None,
+        limit: int = LOG_RECORDS_LIMIT,
+        time_start: datetime.datetime = None,
+    ) -> None:
+        """Returns the preceding consolidated log records.
+
+        Parameters
+        ----------
+        source : str, optional
+            Expression or OCID to filter the "source" field of the OCI log record.
+            Defaults to None.
+        limit : int, optional.
+            Maximum number of records to be returned.
+            If limit is set to None, all logs from time_start to now will be returned.
+            Defaults to 100.
+        time_start : datetime.datetime, optional
+            Starting time for the log query.
+            Defaults to None.
+        """
+        self._print(
+            self._search_and_format(
+                source=source,
+                limit=limit,
+                sort_order=SortOrder.ASC,
+                time_start=time_start,
+            )
+        )
+
+    def _print_log_annotation_message(self) -> None:
+        message = ""
+        for instance in self.logging_instance:
+            if instance.annotation:
+                message = (
+                    f"[{instance.annotation[0].upper()}] - {instance.annotation} log, "
+                    + message
+                )
+        if message:
+            print(message[:-2])
+
+    def _print(self, logs: List[Dict]) -> None:
+        self._print_log_annotation_message()
+        for log in logs:
+            self._print_log_details(log)
+
+    @staticmethod
+    def _print_log_details(log) -> None:
+        annotation = log.get("annotation", "")
+        if annotation:
+            annotation = annotation[0].upper()
+        timestamp = log.get("time", "")
+        if timestamp:
+            timestamp = timestamp.split(".")[0].replace("T", " ")
+        print(f"[{annotation}] - {timestamp} - {log.get('message', '')}")
+
+    def search(
+        self,
+        source: str = None,
+        time_start: datetime.datetime = None,
+        time_end: datetime.datetime = None,
+        limit: int = None,
+        sort_by: str = "datetime",
+        sort_order: str = SortOrder.DESC,
+        log_filter: str = None,
+    ) -> List[oci.loggingsearch.models.SearchResult]:
+        """Searches raw logs.
+
+        Parameters
+        ----------
+        source : str, optional
+            Expression or OCID to filter the "source" field of the OCI log record.
+            Defaults to None.
+        time_start : datetime.datetime, optional
+            Starting time for the log query.
+            Defaults to None.
+        time_end : datetime.datetime, optional.
+            Ending time for the query.
+            Defaults to None.
+        limit : int, optional.
+            Maximum number of records to be returned. All logs will be returned.
+            Defaults to None.
+        sort_by : str, optional.
+            The field for sorting the logs.
+            Defaults to "datetime"
+        sort_order : str, optional.
+            The sort order for the log records. Can be "ASC" or "DESC".
+            Defaults to "DESC".
+        log_filter : str, optional
+            Expression for filtering the logs. This will be the WHERE clause of the query.
+            Defaults to None.
+
+        Returns
+        -------
+        list
+            A list of oci.loggingsearch.models.SearchResult objects
+        """
+        return self._search_and_format(
+            source=source,
+            time_start=time_start,
+            time_end=time_end,
+            limit=limit,
+            sort_by=sort_by,
+            sort_order=sort_order,
+            log_filter=log_filter,
+            need_format=False,
+        )
+
+    def _search_and_format(
+        self,
+        source: str = None,
+        time_start: datetime.datetime = None,
+        time_end: datetime.datetime = None,
+        limit: int = LOG_RECORDS_LIMIT,
+        sort_by: str = "datetime",
+        sort_order: str = SortOrder.DESC,
+        log_filter: str = None,
+        need_format: bool = True,
+    ) -> List[Union[oci.loggingsearch.models.SearchResult, dict]]:
+        """Returns the formatted consolidated log records.
+
+        Parameters
+        ----------
+        source : str, optional
+            Expression or OCID to filter the "source" field of the OCI log record.
+            Defaults to None.
+        time_start : datetime.datetime, optional
+            Starting time for the log query.
+            Defaults to None.
+        time_end : datetime.datetime, optional.
+            Ending time for the query.
+            Defaults to None.
+        limit : int, optional.
+            Maximum number of records to be returned.
+            If limit is set to None, all logs from time_start to now will be returned.
+            Defaults to 100.
+        sort_by : str, optional.
+            The field for sorting the logs.
+            Defaults to "datetime"
+        sort_order : str, optional.
+            The sort order for the log records. Can be "ASC" or "DESC".
+            Defaults to "DESC".
+        log_filter : str, optional
+            Expression for filtering the logs. This will be the WHERE clause of the query.
+            Defaults to None.
+        need_format : bool, optional
+            To decide whether to format the logs or not.
+            Defaults to True.
+
+        Returns
+        -------
+        list
+            A list of oci.loggingsearch.models.SearchResult objects or log records.
+            Each log record is a dictionary with the following keys: `annotation`, `id`, `time`,
+            `message` and `datetime`.
+        """
+        if not time_start:
+            time_start = datetime.datetime.utcnow() - datetime.timedelta(days=14)
+
+        batch_logs = []
+        for instance in self.logging_instance:
+            batch_logs.extend(
+                self._collect_logs(
+                    instance,
+                    source=source,
+                    time_start=time_start,
+                    time_end=time_end,
+                    limit=limit,
+                    sort_by=sort_by,
+                    sort_order=sort_order,
+                    log_filter=log_filter,
+                    need_format=need_format,
+                )
+            )
+
+        # _collect_logs returns a list of either dict or oci.loggingsearch.models.SearchResult
+        # objects based on `need_format` parameter, so below there are two cases for log sorting.
+        if need_format:
+            batch_logs.sort(key=lambda x: x.get("datetime"))
+        else:
+            batch_logs.sort(key=lambda x: x.data.get("datetime"))
+        if limit and len(batch_logs) > limit:
+            batch_logs = batch_logs[:limit]
+        return batch_logs
+
+    def _collect_logs(
+        self,
+        logging_instance: OCILog,
+        source: str = None,
+        time_start: datetime.datetime = None,
+        time_end: datetime.datetime = None,
+        limit: int = LOG_RECORDS_LIMIT,
+        sort_by: str = "datetime",
+        sort_order: str = SortOrder.DESC,
+        log_filter: str = None,
+        need_format: bool = True,
+    ) -> List[Union[oci.loggingsearch.models.SearchResult, dict]]:
+        """Collects logs and formats log records.
+
+        Parameters
+        ----------
+        logging_instance : OCILog
+            OCILog instance.
+        source : str, optional
+            Expression or OCID to filter the "source" field of the OCI log record.
+            Defaults to None.
+        time_start : datetime.datetime, optional
+            Starting time for the log query.
+            Defaults to None.
+        time_end : datetime.datetime, optional.
+            Ending time for the query.
+            Defaults to None.
+        limit : int, optional.
+            Maximum number of records to be returned.
+            If limit is set to None, all logs from time_start to now will be returned.
+            Defaults to 100.
+        sort_by : str, optional.
+            The field for sorting the logs.
+            Defaults to "datetime"
+        sort_order : str, optional.
+            The sort order for the log records. Can be "ASC" or "DESC".
+            Defaults to "DESC".
+        log_filter : str, optional
+            Expression for filtering the logs. This will be the WHERE clause of the query.
+            Defaults to None.
+        need_format : bool, optional
+            To decide whether to format the logs or not.
+            Defaults to True.
+
+        Returns
+        -------
+        list
+            A list of oci.loggingsearch.models.SearchResult objects or log records.
+            Each log record is a dictionary with the following keys: `annotation`, `id`, `time`,
+            `message` and `datetime`.
+        """
+        logs = logging_instance.search(
+            source=source,
+            time_start=time_start,
+            time_end=time_end,
+            limit=limit,
+            sort_by=sort_by,
+            sort_order=sort_order,
+            log_filter=log_filter,
+        )
+        if logs and need_format:
+            return [
+                self._format_and_add_annotation(logging_instance.annotation, log.data)
+                for log in logs
+            ]
+
+        return logs
+
+    @staticmethod
+    def _format_and_add_annotation(annotation: str, data) -> Dict:
+        """Formats log and adds annotation.
+
+        Parameters
+        ----------
+        annotation : str
+            The logging annotation of OCILog instance.
+        data : SearchResult.data
+            The data from oci.loggingsearch.models.SearchResult
+
+        Returns
+        -------
+        dict:
+            Log record dictionary with the following keys: `annotation`, `id`, `time`,
+            `message` and `datetime`.
+        """
+        log_content = data.get("logContent", {})
+        return {
+            "annotation": annotation,
+            "id": log_content.get("id", ""),
+            "message": log_content.get("data", {}).get("message", ""),
+            "time": log_content.get("time", ""),
+            "datetime": data.get("datetime", ""),
+        }
