@@ -7,13 +7,16 @@
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
-from IPython.core.display import display
 
 from cycler import cycler
 import matplotlib as mpl
 import re
 
 from ads.common import logger
+import logging
+
+mlogger = logging.getLogger("matplotlib")
+mlogger.setLevel(logging.WARNING)
 
 mpl.rcParams["image.cmap"] = "BuGn"
 mpl.rcParams["axes.prop_cycle"] = cycler(
@@ -24,7 +27,10 @@ from ads.evaluations.evaluation_plot import EvaluationPlot
 from ads.evaluations.statistical_metrics import ModelEvaluator
 from ads.dataset.dataset_with_target import ADSDatasetWithTarget
 from ads.common.model import ADSModel
-from ads.common.decorator.runtime_dependency import runtime_dependency
+from ads.common.decorator.runtime_dependency import (
+    runtime_dependency,
+    OptionalDependency,
+)
 
 
 class ADSEvaluator(object):
@@ -594,7 +600,12 @@ class ADSEvaluator(object):
                 return df
 
             @runtime_dependency(
-                module="ipywidgets", object="HTML", install_from="oracle-ads[notebook]"
+                module="IPython", install_from=OptionalDependency.NOTEBOOK
+            )
+            @runtime_dependency(
+                module="ipywidgets",
+                object="HTML",
+                install_from=OptionalDependency.NOTEBOOK,
             )
             def _display_metrics(df, data_name, labels, precision):
                 """
@@ -615,11 +626,13 @@ class ADSEvaluator(object):
                 -------
                 Nothing
                 """
+                from IPython.core.display import display, HTML
+
                 display(
                     HTML(
                         _pretty_label(df, labels)
                         .style.apply(highlight_max, axis=1)
-                        .set_precision(precision)
+                        .format(precision=precision)
                         .set_properties(**{"text-align": "center"})
                         .set_table_attributes("class=table")
                         .set_caption(
@@ -628,7 +641,7 @@ class ADSEvaluator(object):
                             + data_name
                             + "):</b></div>"
                         )
-                        .render()
+                        .to_html()
                     )
                 )
 
