@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8; -*-
 
-# Copyright (c) 2022 Oracle and/or its affiliates.
+# Copyright (c) 2022, 2023 Oracle and/or its affiliates.
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 import cgi
@@ -590,10 +590,11 @@ class DataScienceModel(Builder):
         self.dsc_model = self._to_oci_dsc_model(**kwargs).create()
 
         # Create model provenance
-        logger.info("Saving model provenance metadata.")
-        self.dsc_model.create_model_provenance(
-            self.provenance_metadata._to_oci_metadata()
-        )
+        if self.provenance_metadata:
+            logger.info("Saving model provenance metadata.")
+            self.dsc_model.create_model_provenance(
+                self.provenance_metadata._to_oci_metadata()
+            )
 
         # Upload artifacts
         logger.info("Uploading model artifacts.")
