@@ -5,14 +5,14 @@
 # Licensed under the Universal Permissive License v 1.0 as shown at https://oss.oracle.com/licenses/upl/
 
 from ads.model.extractor.model_info_extractor import ModelInfoExtractor
-from ads.common.model_metadata import Framework
+from ads.model.model_metadata import Framework
 from ads.common.decorator.runtime_dependency import (
     runtime_dependency,
     OptionalDependency,
 )
 
 
-class PytorchExtractor(ModelInfoExtractor):
+class PyTorchExtractor(ModelInfoExtractor):
     """Class that extract model metadata from pytorch models.
 
     Attributes
@@ -81,3 +81,7 @@ class PytorchExtractor(ModelInfoExtractor):
            The hyperparameters of the model.
         """
         return None
+
+
+class PytorchExtractor(PyTorchExtractor):
+    pass
