@@ -17,14 +17,14 @@ from ads.common.decorator.runtime_dependency import (
 from ads.common.data_serializer import InputDataSerializer
 from ads.model.extractor.xgboost_extractor import XgboostExtractor
 from ads.model.generic_model import (
-    GenericModel,
+    FrameworkSpecificModel,
     DEFAULT_ONNX_FORMAT_MODEL_FILE_NAME,
     DEFAULT_JSON_FORMAT_MODEL_FILE_NAME,
 )
 from ads.model.model_properties import ModelProperties
 
 
-class XGBoostModel(GenericModel):
+class XGBoostModel(FrameworkSpecificModel):
     """XGBoostModel class for estimators from xgboost framework.
 
     Attributes
@@ -122,6 +122,8 @@ class XGBoostModel(GenericModel):
     >>> xgboost_model.predict(X_test)
     """
 
+    _PREFIX = "xgboost"
+
     @runtime_dependency(module="xgboost", install_from=OptionalDependency.BOOSTED)
     def __init__(
         self,
@@ -462,35 +464,3 @@ class XGBoostModel(GenericModel):
                 "`initial_types` can not be detected. Please directly pass initial_types."
             )
         return auto_generated_initial_types
-
-    def get_data_serializer(
-        self,
-        data: Union[
-            Dict,
-            str,
-            List,
-            np.ndarray,
-            pd.core.series.Series,
-            pd.core.frame.DataFrame,
-        ],
-    ):
-        """Returns serializable input data.
-
-        Parameters
-        ----------
-        data: Union[Dict, str, list, numpy.ndarray, pd.core.series.Series,
-        pd.core.frame.DataFrame]
-            Data expected by the model deployment predict API.
-
-        Returns
-        -------
-        InputDataSerializer
-            A class containing serialized input data and original data type
-            information.
-
-        Raises
-        ------
-        TypeError
-            if provided data type is not supported.
-        """
-        return InputDataSerializer(data)
