@@ -23,9 +23,11 @@ from ads.opctl.constants import (
     DEFAULT_ADS_CONFIG_FOLDER,
     ADS_JOBS_CONFIG_FILE_NAME,
     ADS_CONFIG_FILE_NAME,
-    ADS_JOBS_CONFIG_FILE_NAME,
+    ADS_ML_PIPELINE_CONFIG_FILE_NAME,
     ADS_DATAFLOW_CONFIG_FILE_NAME,
+    ADS_LOCAL_BACKEND_CONFIG_FILE_NAME,
     DEFAULT_NOTEBOOK_SESSION_CONDA_DIR,
+    BACKEND_NAME,
 )
 
 
@@ -174,10 +176,13 @@ class ConfigMerger(ConfigProcessor):
             return {}
 
     def _get_service_config(self, oci_profile: str, ads_config_folder: str) -> Dict:
-        if self.config["execution"].get("backend", None) == "dataflow":
-            config_file = ADS_DATAFLOW_CONFIG_FILE_NAME
-        else:
-            config_file = ADS_JOBS_CONFIG_FILE_NAME
+        backend = self.config["execution"].get("backend", None)
+        backend_config = {
+            BACKEND_NAME.DATAFLOW.value: ADS_DATAFLOW_CONFIG_FILE_NAME,
+            BACKEND_NAME.PIPELINE.value: ADS_ML_PIPELINE_CONFIG_FILE_NAME,
+            BACKEND_NAME.LOCAL.value: ADS_LOCAL_BACKEND_CONFIG_FILE_NAME,
+        }
+        config_file = backend_config.get(backend, ADS_JOBS_CONFIG_FILE_NAME)
 
         if os.path.exists(os.path.join(ads_config_folder, config_file)):
             parser = read_from_ini(os.path.join(ads_config_folder, config_file))
